<?php
/**
 * Plugin Name: Tickera - Tickets Left in Tickets Table
 * Plugin URI: http://tickera.com/
 * Description: Displays the number of tickets left for each of the ticket types in the table of event tickets
 * Author: Tickera.com
 * Author URI: http://tickera.com/
 * Version: 2.1
 * TextDomain: tc
 * Copyright 2019 Tickera (https://tickera.com/)
 */

if ( ! defined( 'ABSPATH' ) )
    exit; // Exit if accessed directly

if ( ! class_exists( 'TC_Custom_Show_Tickets_Left_In_Tickets_Table' ) ) {

    class TC_Custom_Show_Tickets_Left_In_Tickets_Table {

        var $version = '2.1';
        var $title = 'Tickera - Tickets Left in Tickets Table';
        var $name = 'custom-show-tickets-left-in-tickets-table';
        var $dir_name = 'custom-show-tickets-left-in-tickets-table';
        var $location = 'plugins';
        var $plugin_dir = '';
        var $plugin_url = '';

        function __construct() {

            self::init_vars();
            add_action( 'activated_plugin', array( $this, 'plugin_dependencies' ), 99 );

            if ( is_plugin_active( 'bridge-for-woocommerce/bridge-for-woocommerce.php' ) ) {
                add_action( 'tc_wb_event_col_title_before_ticket_price', array( $this, 'tc_woo_custom_tickets_left_title' ), 10, 1 );
                add_action( 'tc_wb_event_col_value_before_ticket_price', array( $this, 'tc_woo_custom_tickets_left_value' ), 10, 1 );
            }

            add_action( 'tc_event_col_title_before_ticket_price', array( $this, 'tc_custom_tickets_left_title' ), 10, 1 );
            add_action( 'tc_event_col_value_before_ticket_price', array( $this, 'tc_custom_tickets_left_value' ), 10, 1 );
        }

        function init_vars() {

            if ( defined( 'WP_PLUGIN_URL' ) && defined( 'WP_PLUGIN_DIR' ) && file_exists( WP_PLUGIN_DIR . '/' . $this->dir_name . '/' . basename( __FILE__ ) ) ) {
                $this->location = 'subfolder-plugins';
                $this->plugin_dir = WP_PLUGIN_DIR . '/' . $this->dir_name . '/';
                $this->plugin_url = plugins_url( '/', __FILE__ );

            } elseif ( defined( 'WP_PLUGIN_URL' ) && defined( 'WP_PLUGIN_DIR' ) && file_exists( WP_PLUGIN_DIR . '/' . basename( __FILE__ ) ) ) {
                $this->location = 'plugins';
                $this->plugin_dir = WP_PLUGIN_DIR . '/';
                $this->plugin_url = plugins_url( '/', __FILE__ );

            } elseif ( is_multisite() && defined( 'WPMU_PLUGIN_URL' ) && defined( 'WPMU_PLUGIN_DIR' ) && file_exists( WPMU_PLUGIN_DIR . '/' . basename( __FILE__ ) ) ) {
                $this->location = 'mu-plugins';
                $this->plugin_dir = WPMU_PLUGIN_DIR;
                $this->plugin_url = WPMU_PLUGIN_URL;

            } else {
                wp_die( sprintf( __( 'There was an issue determining where %s is installed. Please reinstall it.', 'tc' ), $this->title ) );
            }
        }

        /**
         * Load this plugin the very last to ensure all the dependencies loaded first.
         */
        function plugin_dependencies() {

            $plugin_slug = basename( __DIR__ ) . '/' . basename( __FILE__ );
            $active_plugins = get_option( 'active_plugins', [] );
            $index = array_search( $plugin_slug, $active_plugins );

            if ( $index !== false ) {
                unset( $active_plugins[ $index ] );
                $active_plugins[] = $plugin_slug;
                update_option( 'active_plugins', array_values( $active_plugins ) );
            }
        }

        function tc_woo_custom_tickets_left_title() { ?>
            <th>Tickets left</th>
        <?php }

        function tc_woo_custom_tickets_left_value( $ticket_type ) {
            global $product;
            $product = wc_get_product( $ticket_type );
            $stock = $product->get_stock_quantity(); ?>
            <td><?php echo $stock; ?></td>
        <?php }

        function tc_custom_tickets_left_title() { ?>
            <th>Tickets left</th>
        <?php }

        function tc_custom_tickets_left_value( $ticket_type ) { ?>
            <td> <?php echo do_shortcode( '[tickets_left ticket_type_id="' . $ticket_type . '"]' ) ?> </td>
        <?php }
    }

    new TC_Custom_Show_Tickets_Left_In_Tickets_Table;
}




